/*
 * Guifications - The end all, be all, toaster popup plugin
 * Copyright (C) 2003-2004 Gary Kramlich
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifndef GF_PREFERENCES_H
#define GF_PREFERENCES_H

#include "gtkplugin.h"

#define GF_PREF_ROOT "/plugins/gtk/amc_grim"
#define GF_PREF_PLUGIN_ROOT "/plugins/gtk/amc_grim/guifications2"

#define GF_PREF_BEHAVIOR_ROOT "/plugins/gtk/amc_grim/guifications2/behavior"
#define GF_PREF_BEHAVIOR_NOTIFICATIONS "/plugins/gtk/amc_grim/guifications2/behavior/notifications"
#define GF_PREF_BEHAVIOR_DISPLAY_TIME "/plugins/gtk/amc_grim/guifications2/behavior/display_time"
#define GF_PREF_BEHAVIOR_THROTTLE "/plugins/gtk/amc_grim/guifications2/behavior/throttle"
#define GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY "/plugins/gtk/amc_grim/guifications2/behavior/show_while_away"

#define GF_PREF_APPEARANCE_ROOT "/plugins/gtk/amc_grim/guifications2/appearance"
#define GF_PREF_APPEARANCE_POSITION "/plugins/gtk/amc_grim/guifications2/appearance/position"
#define GF_PREF_APPEARANCE_VERTICAL "/plugins/gtk/amc_grim/guifications2/appearance/vertical"
#define GF_PREF_APPEARANCE_ANIMATE "/plugins/gtk/amc_grim/guifications2/appearance/animate"

#define GF_PREF_MOUSE_ROOT "/plugins/gtk/amc_grim/guifications2/mouse"
#define GF_PREF_MOUSE_LEFT "/plugins/gtk/amc_grim/guifications2/mouse/left"
#define GF_PREF_MOUSE_MIDDLE "/plugins/gtk/amc_grim/guifications2/mouse/middle"
#define GF_PREF_MOUSE_RIGHT "/plugins/gtk/amc_grim/guifications2/mouse/right"

#define GF_PREF_LOADED_THEMES "/plugins/gtk/amc_grim/guifications2/themes"

#define GF_PREF_ADVANCED_ROOT "/plugins/gtk/amc_grim/guifications2/advanced"
#define GF_PREF_ADVANCED_RELEASE_NOTIFICATION "/plugins/gtk/amc_grim/guifications2/advanced/release_notification"
#define GF_PREF_ADVANCED_RELEASE_LAST_CHECK "/plugins/gtk/amc_grim/guifications2/advanced/release_last_check"

#if GTK_CHECK_VERSION(2,2,0)
#define GF_PREF_ADVANCED_SCREEN "/plugins/gtk/amc_grim/guifications2/advanced/screen"
#define GF_PREF_ADVANCED_MONITOR "/plugins/gtk/amc_grim/guifications2/advanced/monitor"
#endif /* GTK_CHECK_VERSION(2,2,0) */

GtkWidget *gf_preferences_get_frame(GaimPlugin *plugin);
void gf_preferences_refresh_themes_list();

void gf_preferences_add();

#endif
